==> gauche_0.8.7.orig.tar.gz: Gauche-0.8.7/ext/fcntl/gauche/fcntl.h <==
/*
 * fcntl.h - fcntl interface
 *
 *   Copyright (c) 2000-2003 Shiro Kawai, All rights reserved.
 * 
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 *   3. Neither the name of the authors nor the names of its contributors
 *      may be used to endorse or promote products derived from this
 *      software without specific prior written permission.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *   TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  $Id: fcntl.h,v 1.2 2003/07/05 03:29:10 shirok Exp $
 */

#ifndef GAUCHE_FCNTL_H
#define GAUCHE_FCNTL_H

#include <gauche.h>
#include <fcntl.h>

typedef struct ScmSysFlockRec {
    SCM_HEADER;
    struct flock lock;
} ScmSysFlock;

SCM_CLASS_DECL(Scm_SysFlockClass);
#define SCM_CLASS_SYS_FLOCK   (&Scm_SysFlockClass)
#define SCM_SYS_FLOCK(obj)    ((ScmSysFlock*)(obj))
#define SCM_SYS_FLOCK_P(obj)  (SCM_XTYPEP(obj, SCM_CLASS_SYS_FLOCK))

extern ScmObj Scm_MakeSysFlock(void);
extern ScmObj Scm_SysFcntl(ScmObj port_or_fd, int op, ScmObj arg);

#endif /* GAUCHE_FCNTL_H */

==> gauche_0.8.13.orig.tar.gz: Gauche-0.8.13/ext/fcntl/gauche/fcntl.h <==
/*
 * fcntl.h - fcntl interface
 *
 *   Copyright (c) 2000-2007  Shiro Kawai  <shiro@acm.org>
 * 
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 *   3. Neither the name of the authors nor the names of its contributors
 *      may be used to endorse or promote products derived from this
 *      software without specific prior written permission.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *   TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  $Id: fcntl.h,v 1.4 2007/09/15 04:00:18 shirok Exp $
 */

#ifndef GAUCHE_FCNTL_H
#define GAUCHE_FCNTL_H

#include <gauche.h>
#include <fcntl.h>

#if defined(EXTFCNTL_EXPORTS)
#define LIBGAUCHE_EXT_BODY
#endif
#include <gauche/extern.h>      /* redefine SCM_EXTERN */

typedef struct ScmSysFlockRec {
    SCM_HEADER;
    struct flock lock;
} ScmSysFlock;

SCM_CLASS_DECL(Scm_SysFlockClass);
#define SCM_CLASS_SYS_FLOCK   (&Scm_SysFlockClass)
#define SCM_SYS_FLOCK(obj)    ((ScmSysFlock*)(obj))
#define SCM_SYS_FLOCK_P(obj)  (SCM_XTYPEP(obj, SCM_CLASS_SYS_FLOCK))

extern ScmObj Scm_MakeSysFlock(void);
extern ScmObj Scm_SysFcntl(ScmObj port_or_fd, int op, ScmObj arg);

#endif /* GAUCHE_FCNTL_H */
